@@ -3,7 +3,6 @@ package AnyEvent::HTTPD::SendMultiHeaderPatch;
 use 5.006;
 use strict;
 use warnings FATAL => 'all';
-no warnings 'redefine';
 
 use AnyEvent::HTTPD::HTTPConnection;
 
@@ -14,44 +13,52 @@ AnyEvent::HTTPD::SendMultiHeaderPatch -
 
 =head1 VERSION
 
-Version 0.1.3
+Version 0.01
 
 =cut
 
-our $VERSION = '0.001003';
+our $VERSION = '0.01';
 
 use AnyEvent::HTTPD;
-use AnyEvent::HTTPD::Util;
-use AnyEvent::HTTPD::HTTPConnection;
 
-use Scalar::Util qw(weaken);
+package AnyEvent::HTTPD::Util;
 
-push @AnyEvent::HTTPD::Util::EXPORT, qw(header_add header_gets);
+use strict;
+use warnings;
 
-*AnyEvent::HTTPD::Util::header_add = sub {
+our @EXPORT;
+push @EXPORT, qw(header_add header_gets);
+
+sub header_add {
     my ($hdrs, $name, $value) = @_;
-    $name = AnyEvent::HTTPD::Util::_header_transform_case_insens ($hdrs, $name);
+    $name = _header_transform_case_insens ($hdrs, $name);
     if( exists $hdrs->{$name} ) {
         $hdrs->{$name} .= "\0".$value;
     }
     else {
        $hdrs->{$name} = $value;
     }
-};
+}
 
-*AnyEvent::HTTPD::Util::header_gets = sub {
+sub header_gets {
     my ($hdrs, $name) = @_;
-    $name = AnyEvent::HTTPD::Util::_header_transform_case_insens ($hdrs, $name);
+    $name = _header_transform_case_insens ($hdrs, $name);
     exists $hdrs->{$name} ? [split /\0/, $hdrs->{$name}] : []
-};
+}
 
-*AnyEvent::HTTPD::HTTPConnection::response = sub {
+package AnyEvent::HTTPD::HTTPConnection;
+
+use strict;
+use warnings;
+no warnings 'redefine';
+
+sub response {
    my ($self, $code, $msg, $hdr, $content, $no_body) = @_;
    return if $self->{disconnected};
    return unless $self->{hdl};
 
    my $res = "HTTP/1.0 $code $msg\015\012";
-   header_set ($hdr, 'Date' => AnyEvent::HTTPD::HTTPConnection::_time_to_http_date time)
+   header_set ($hdr, 'Date' => _time_to_http_date time)
       unless header_exists ($hdr, 'Date');
    header_set ($hdr, 'Expires' => header_get ($hdr, 'Date'))
       unless header_exists ($hdr, 'Expires');
@@ -126,7 +133,7 @@ push @AnyEvent::HTTPD::Util::EXPORT, qw(header_add header_gets);
       $self->{hdl}->push_write ($res);
       $self->response_done;
    }
-};
+}
 
 =head1 SYNOPSIS
 
